@@ -78,19 +78,25 @@ setMethod("belief.propagation",
 
               quantiles <- quantiles(net)
 
+              is.discrete <- discreteness(net)
+
               # discretize continuous observed variables
               observed.vals.disc <- c()
               if (length(observed.vars) > 0) {
                 for (i in 1:length(observed.vars)) {
                    ovr <- observed.vars[i]
                    ovl <- observed.vals[i]
-                   q <- quantiles[[ovr]]
-                   cv <- cut(ovl, q, labels=FALSE, include.lowest=TRUE)
-                   if (is.na(cv)) {
-                     if (ovl <= q[1]) cv <- 1
-                     else cv <- node.sizes[ovr]
+                   if (is.discrete[ovr]) {
+                     observed.vals.disc <- c(observed.vals.disc, ovl)
+                   } else {
+                     q <- quantiles[[ovr]]
+                     cv <- cut(ovl, q, labels=FALSE, include.lowest=TRUE)
+                     if (is.na(cv)) {
+                       if (ovl <= q[1]) cv <- 1
+                       else cv <- node.sizes[ovr]
+                     }
+                     observed.vals.disc <- c(observed.vals.disc, cv)
                    }
-                   observed.vals.disc <- c(observed.vals.disc, cv)
                 }
               }
               
@@ -194,18 +200,6 @@ setMethod("belief.propagation",
                   obs.var <- observed.vars[var]
                   obs.val <- observed.vals.disc[var]
 
-                  ## preliminary: continuous observations need to be discretized 
-                  #if (length(quantiles) > 0 && length(quantiles[[obs.var]] > 0)) {
-                  #  # check for values outside the quantiles -- probably a horrible workaround, though
-                  #  if (obs.val <= quantiles[[obs.var]][1]) {
-                  #    obs.val <- 1
-                  #  } else if (obs.val >= quantiles[[obs.var]][node.sizes[obs.var]]) {
-                  #    obs.val <- node.sizes[obs.var]
-                  #  } else {
-                  #    obs.val <- cut( obs.val, quantiles[[obs.var]], labels=FALSE, include.lowest=TRUE)
-                  #  }
-                  #}
-
                   if (obs.val <= 0 || obs.val > node.sizes[obs.var])
                   {
                     message(cat("Variable", obs.var, "cannot take value", obs.val, ", skipping..."))
